# QMCblip

QMC Based Learning of Interatomic Potentials

[![PyPI version](https://badge.fury.io/py/QMCblip.svg)](https://badge.fury.io/py/QMCblip)

# Installation

You can install this package by cloning this repository:
```
git clone https://github.com/NLESC-JCER/QMCblip.git
cd QMCblip
pip install .
```

or by installing it from Pypi:
```
pip install qmcblip
```
## Documentation

The documentation of this code can be found on https://qmcblip.readthedocs.io/.
